==> ember-junction-2.1.16.tgz: package/blueprints/ember-junction/files/app/components/types/modules/new.js <==
import Component from '@glimmer/component';
import { action } from '@ember/object';
import { service } from '@ember/service';
import { tracked } from '@glimmer/tracking';
import { Modal } from 'bootstrap';
import { later } from '@ember/runloop';

export default class TypesModulesNewComponent extends Component {
  @service type;
  @service module;
  @service colormodes;
  @tracked moduleName = '';
  @service types;
  @tracked modelBox = null;

  convertToSlug = (Text) => {
    return Text.toLowerCase()
      .replace(/ /g, '_')
      .replace(/[^\w-]+/g, '')
      .replace(/-/g, '_');
  };

  @action
  initModel() {
    this.modelBox = new Modal(document.getElementById('newModuleModel'), {});

    const myModalEl = document.getElementById('newModuleModel');
    myModalEl.addEventListener('hidden.bs.modal', async (event) => {
      this.types.fetchAgain();
    });
  }

  @action
  async save() {
    if (this.moduleName != '') {
      let slug = this.type.currentType.slug;
      var exists = false;

      this.types.json.modules[slug].modules.forEach((module) => {
        if (
          module.input_slug == this.convertToSlug(this.moduleName)
        ) {
          exists = true;
        }
      });

      if (exists) {
        alert('A module with this name already exists.');
      } else {
        this.types.json.modules[slug].modules.push({
          input_slug: this.convertToSlug(this.moduleName),
          input_type: 'text',
          input_placeholder: this.moduleName,
          list_field: false,
          list_searchable: false,
          list_sortable: false,
          var_type: 'string'
        });
        await this.types.json.save();
        this.modelBox.hide();
        this.moduleName = "";
        this.types.fetchAgain();
        document.querySelector('#track-'+slug).click();
      }
    } else {
      alert('Module name field is compulsory.');
    }
  }
}

==> ember-junction-2.2.11.tgz: package/blueprints/ember-junction/files/app/components/types/modules/new.js <==
import Component from '@glimmer/component';
import { action } from '@ember/object';
import { service } from '@ember/service';
import { tracked } from '@glimmer/tracking';
import { Modal } from 'bootstrap';
import { later } from '@ember/runloop';

export default class TypesModulesNewComponent extends Component {
  @service type;
  @service module;
  @service colormodes;
  @tracked moduleName = '';
  @service types;
  @tracked modelBox = null;

  convertToSlug = (Text) => {
    return Text.toLowerCase()
      .replace(/ /g, '_')
      .replace(/[^\w-]+/g, '')
      .replace(/-/g, '_');
  };

  @action
  initModel() {
    this.modelBox = new Modal(document.getElementById('newModuleModel'), {});

    const myModalEl = document.getElementById('newModuleModel');
    myModalEl.addEventListener('hidden.bs.modal', async (event) => {
      this.types.fetchAgain();
    });
  }

  @action
  async save() {
    if (this.moduleName != '') {
      let slug = this.type.currentType.slug;
      var exists = false;

      this.types.json.modules[slug].modules.forEach((module) => {
        if (module.input_slug == this.convertToSlug(this.moduleName)) {
          exists = true;
        }
      });

      if (exists) {
        alert('A module with this name already exists.');
      } else {
        this.types.json.modules[slug].modules.push({
          input_slug: this.convertToSlug(this.moduleName),
          input_type: 'text',
          input_placeholder: this.moduleName,
          list_field: false,
          list_searchable: false,
          list_sortable: false,
          var_type: 'string',
        });
        await this.types.json.save();
        this.modelBox.hide();
        this.moduleName = '';
        this.types.fetchAgain();
        document.querySelector('#track-' + slug).click();
      }
    } else {
      alert('Module name field is compulsory.');
    }
  }
}
